@@ -1,6 +1,6 @@
 package Statocles::App;
 # ABSTRACT: Base role for Statocles applications
-$Statocles::App::VERSION = '0.047';
+$Statocles::App::VERSION = '0.048';
 use Statocles::Base 'Role';
 use Statocles::Link;
 requires 'pages';
@@ -52,8 +52,14 @@ around pages => sub {
 
 sub url {
     my ( $self, $url ) = @_;
+    my $base = $self->url_root;
     $url =~ s{/index[.]html$}{/};
-    return join "/", $self->url_root, $url;
+
+    # Remove the / from both sides of the join so we don't double up
+    $base =~ s{/$}{};
+    $url =~ s{^/}{};
+
+    return join "/", $base, $url;
 }
 
 
@@ -78,13 +84,31 @@ Statocles::App - Base role for Statocles applications
 
 =head1 VERSION
 
-version 0.047
+version 0.048
+
+=head1 SYNOPSIS
+
+    package MyApp;
+    use Statocles::Base 'Class';
+    with 'Statocles::App';
+
+    sub pages {
+        return Statocles::Page::Content->new(
+            path => '/index.html',
+            content => 'Hello, World',
+        );
+    }
 
 =head1 DESCRIPTION
 
-A Statocles App turns L<documents|Statocles::Documents> into a set of
-L<pages|Statocles::Pages> that can then be written to the filesystem (or served
-directly, if desired).
+A Statocles App creates a set of L<pages|Statocles::Pages> that can then be
+written to the filesystem (or served directly, if desired).
+
+Pages can be created from L<documents|Statocles::Documents> stored in a
+L<store|Statocles::Store> (see L<Statocles::Page::Document>), files stored in a
+store (see L<Statocles::Page::File>), lists of content (see
+L<Statocles::Page::List>), or anything at all (see
+L<Statocles::Page::Content>).
 
 =head1 ATTRIBUTES
 
@@ -120,6 +144,32 @@ Get a URL to a page in this application. Prepends the L</url_root> if necessary.
 Create a link to a page in this application. C<%args> are attributes to be given to
 L<Statocles::Link> constructor.
 
+=head1 INCLUDED APPS
+
+These applications are included with the core Statocles distribution.
+
+=over 4
+
+=item L<Statocles::App::Blog>
+
+=item L<Statocles::App::Plain>
+
+=item L<Statocles::App::Static>
+
+=item L<Statocles::App::Perldoc>
+
+=back
+
+=head1 SEE ALSO
+
+=over 4
+
+=item L<Statocles::Store>
+
+=item L<Statocle::Page>
+
+=back
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
