@@ -1,12 +1,11 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.047';
+$Statocles::App::Blog::VERSION = '0.048';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store::File;
 use Statocles::Page::Document;
 use Statocles::Page::List;
-use Statocles::Page::Feed;
 
 with 'Statocles::App';
 
@@ -178,7 +177,7 @@ sub post_files {
         # index.markdown is the post itself
         next if $path =~ m{/index[.]markdown$};
 
-        if ( $path =~ /[.]markdown/ ) {
+        if ( $path =~ /[.]markdown$/ ) {
             my $page_path = $path;
             $page_path =~ s{[.]\w+$}{.html};
 
@@ -255,12 +254,10 @@ sub _make_post_page {
 my %FEEDS = (
     rss => {
         text => 'RSS',
-        type => 'application/rss+xml',
         template => 'index.rss',
     },
     atom => {
         text => 'Atom',
-        type => 'application/atom+xml',
         template => 'index.atom',
     },
 );
@@ -299,13 +296,22 @@ sub index {
     my @feed_pages;
     my @feed_links;
     for my $feed ( sort keys %FEEDS ) {
-        my $page = Statocles::Page::Feed->new(
+        my $page = Statocles::Page::List->new(
             app => $self,
-            type => $FEEDS{ $feed }{ type },
-            page => $index,
+            pages => $index->pages,
             path => 'index.' . $feed,
             template => $self->site->theme->template( blog => $FEEDS{$feed}{template} ),
+            links => {
+                alternate => [
+                    $self->link(
+                        href => $index->path,
+                        title => 'index',
+                        type => $index->type,
+                    ),
+                ],
+            },
         );
+
         push @feed_pages, $page;
         push @feed_links, $self->link(
             text => $FEEDS{ $feed }{ text },
@@ -350,13 +356,22 @@ sub tag_pages {
         for my $feed ( sort keys %FEEDS ) {
             my $tag_file = $self->_tag_url( $tag ) . '.' . $feed;
 
-            my $page = Statocles::Page::Feed->new(
-                type => $FEEDS{ $feed }{ type },
+            my $page = Statocles::Page::List->new(
                 app => $self,
-                page => $index,
+                pages => $index->pages,
                 path => join( "/", 'tag', $tag_file ),
                 template => $self->site->theme->template( blog => $FEEDS{$feed}{template} ),
+                links => {
+                    alternate => [
+                        $self->link(
+                            href => $index->path,
+                            title => $tag,
+                            type => $index->type,
+                        ),
+                    ],
+                },
             );
+
             push @feed_pages, $page;
             push @feed_links, $self->link(
                 text => $FEEDS{ $feed }{ text },
@@ -460,7 +475,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 DESCRIPTION
 
@@ -552,7 +567,7 @@ Get all the post collateral files.
 =head2 index()
 
 Get the index page (a L<list page|Statocles::Page::List>) for this application.
-This includes all the relevant L<feed pages|Statocles::Page::Feed>.
+This includes all the relevant feed pages.
 
 =head2 tag_pages()
 
