@@ -1,13 +1,21 @@
 package Statocles::Link;
 # ABSTRACT: A link object to build <a> and <link> tags
-$Statocles::Link::VERSION = '0.047';
+$Statocles::Link::VERSION = '0.048';
 use Statocles::Base 'Class';
+use Scalar::Util qw( blessed );
 
 
 has href => (
     is => 'rw',
     isa => Str,
     required => 1,
+    coerce => sub {
+        my ( $href ) = @_;
+        if ( blessed $href && $href->isa( 'Path::Tiny' ) ) {
+            return $href->absolute( '/' )->stringify;
+        }
+        return $href;
+    },
 );
 
 
@@ -69,7 +77,7 @@ Statocles::Link - A link object to build <a> and <link> tags
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
