@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::VERSION = '0.047';
+$Statocles::Page::VERSION = '0.048';
 use Statocles::Base 'Role';
 use Statocles::Template;
 
@@ -27,6 +27,37 @@ has path => (
 );
 
 
+our %TYPES = (
+    # text
+    html => 'text/html',
+    markdown => 'text/markdown',
+    css => 'text/css',
+
+    # image
+    jpg => 'image/jpeg',
+    jpeg => 'image/jpeg',
+    png => 'image/png',
+    gif => 'image/gif',
+
+    # application
+    rss => 'application/rss+xml',
+    atom => 'application/atom+xml',
+    js => 'application/javascript',
+    json => 'application/json',
+);
+
+has type => (
+    is => 'ro',
+    isa => Str,
+    lazy => 1,
+    default => sub {
+        my ( $self ) = @_;
+        my ( $ext ) = $self->path =~ /[.]([^.]+)$/;
+        return $TYPES{ $ext };
+    },
+);
+
+
 has date => (
     is => 'ro',
     isa => InstanceOf['Time::Piece'],
@@ -115,7 +146,20 @@ sub render {
 
 sub links {
     my ( $self, $name ) = @_;
-    return $self->_links->{ $name } ? @{ $self->_links->{ $name } } : ();
+    my @links = $self->_links->{ $name } ? @{ $self->_links->{ $name } } : ();
+    return wantarray ? @links : $links[0];
+}
+
+
+sub basename {
+    my ( $self ) = @_;
+    return $self->path->basename;
+}
+
+
+sub dirname {
+    my ( $self ) = @_;
+    return $self->path->parent->stringify;
 }
 
 1;
@@ -130,7 +174,7 @@ Statocles::Page - Render documents into HTML
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 DESCRIPTION
 
@@ -152,6 +196,11 @@ The application this page came from, so we can give it to the templates.
 
 The absolute URL path to save this page to.
 
+=head2 type
+
+The MIME type of this page. By default, will use the L<path's|/path> file extention
+to detect a likely type.
+
 =head2 date
 
 The date of this page. Used for last updated date and blog post dates.
@@ -239,7 +288,18 @@ with the L<layout|Statocles::Page/layout>.
 =head2 links( KEY )
 
 Get the links set for the given key. See L<the links attribute|/links> for some
-commonly-used keys. Returns a list of L<link objects|Statocles::Link>.
+commonly-used keys. Returns a list of L<link objects|Statocles::Link>. In
+scalar context, returns the first link in the list.
+
+=head2 basename()
+
+Get the base file name of this page. Everything after the last C</>.
+
+=head2 dirname()
+
+Get the full directory to this page. Anything that isn't part of L</basename>.
+
+There will not be a trailing slash unless it is the root directory.
 
 =head1 SEE ALSO
 
