@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.047';
+$Statocles::Page::Document::VERSION = '0.048';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -50,12 +50,18 @@ has '+_links' => (
     default => sub { $_[0]->document->links },
 );
 
+sub _render_content_template {
+    my ( $self, $content, $vars ) = @_;
+    my $tmpl = $self->site->theme->build_template( $self->path, $content );
+    my $rendered = $tmpl->render( %$vars, $self->vars, self => $self->document );
+    return $rendered;
+}
+
 
 sub content {
     my ( $self, %vars ) = @_;
     my $content = $self->document->content;
-    my $tmpl = $self->site->theme->build_template( $self->path, $content );
-    my $rendered = $tmpl->render( %vars, $self->vars, self => $self->document );
+    my $rendered = $self->_render_content_template( $content, \%vars );
     return $self->markdown->markdown( $rendered );
 }
 
@@ -71,7 +77,10 @@ sub vars {
 sub sections {
     my ( $self ) = @_;
     my @sections = split /\n---\n/, $self->document->content;
-    return map { $self->markdown->markdown( $_ ) } @sections;
+    return
+        map { $self->markdown->markdown( $_ ) }
+        map { $self->_render_content_template( $_, {} ) }
+        @sections;
 }
 
 
@@ -110,7 +119,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 DESCRIPTION
 
