@@ -1,17 +1,40 @@
 package Statocles::Page::List;
 # ABSTRACT: A page presenting a list of other pages
-$Statocles::Page::List::VERSION = '0.047';
+$Statocles::Page::List::VERSION = '0.048';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use List::Util qw( max );
 use Statocles::Template;
+use Statocles::Page::ListItem;
 
 
-has pages => (
+has _pages => (
     is => 'ro',
     isa => ArrayRef[ConsumerOf['Statocles::Page']],
+    init_arg => 'pages',
 );
 
+sub pages {
+    my ( $self ) = @_;
+
+    my %rewrite;
+    if ( $self->type eq 'application/rss+xml' || $self->type eq 'application/atom+xml' ) {
+        %rewrite = ( rewrite_mode => 'full' );
+    }
+
+    my @pages;
+    for my $page ( @{ $self->_pages } ) {
+        # Always re-wrap the page, even if it's already wrapped,
+        # to change the rewrite_mode
+        push @pages, Statocles::Page::ListItem->new(
+            %rewrite,
+            page => $page->isa( 'Statocles::Page::ListItem' ) ? $page->page : $page,
+        );
+    }
+
+    return \@pages;
+}
+
 
 has [qw( next prev )] => (
     is => 'rw',
@@ -95,7 +118,7 @@ Statocles::Page::List - A page presenting a list of other pages
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 DESCRIPTION
 
