@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.047';
+$Statocles::Site::VERSION = '0.048';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -239,7 +239,7 @@ sub build {
             for my $attr ( qw( src href ) ) {
                 for my $el ( $dom->find( "[$attr]" )->each ) {
                     my $url = $el->attr( $attr );
-                    next unless $url =~ m{^/};
+                    next unless $url =~ m{^/[^/]};
 
                     # Rewrite links to the index app's index page
                     if ( $index_root && $url =~ m{^$index_root(?:/index[.]html)?$} ) {
@@ -334,7 +334,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
